<?php
/**
 * Plugin Name: Dadevarzan WordPress recipe plugin
 * Plugin URI: https://wordpress.org/plugins/dadevarzan-wp-recipe
 * GitHub Plugin URI: https://github.com/dadevarzan/dadevarzan-wp-recipe
 * Description: recipe post type for wordpress
 * Version: 1.2.6
 * Author: Dadevarzan Team
 * Author URI: http://www.dadevarzan.com
 * Text Domain: dadevarzan-wp-recipe
 * Domain Path: /languages
*/

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}

if ( !class_exists( 'dadevarzanWpRecipe' ) ) {

    class dadevarzanWpRecipe
    {

        public static function initialize()
        {
            add_action( 'plugins_loaded', 'dadevarzanWpRecipe::load_text_domain' );
            add_action( 'init', 'dadevarzanWpRecipe::add_post_type' );
            add_action( 'init', 'dadevarzanWpRecipe::add_fields' );
            add_action('init', 'dadevarzanWpRecipe::add_taxonomy');
            add_action('init', 'dadevarzanWpRecipe::add_role_caps');
            add_action( 'plugins_loaded', 'dadevarzanWpRecipe::load_templates' );

        }

        public static function add_post_type()
        {

            $labels = array(
                "name" => __('Recipes', 'dadevarzan-wp-recipe'),
                "singular_name" => __('Recipe', 'dadevarzan-wp-recipe'),
                "all_items" => __('All Recipes', 'dadevarzan-wp-recipe'),
                "add_new" => __('Add Recipe', 'dadevarzan-wp-recipe'),
                "add_new_item" => __('Add New Recipe', 'dadevarzan-wp-recipe'),
                "edit_item" => __('Edit Recipe', 'dadevarzan-wp-recipe'),
                "new_item" => __('New Recipe', 'dadevarzan-wp-recipe'),
                "view_item" => __('View Recipe', 'dadevarzan-wp-recipe'),
            );

            $args = array(
                "label" => __('Recipe', 'dadevarzan-wp-recipe'),
                "labels" => $labels,
                "description" => "",
                "public" => true,
                "publicly_queryable" => true,
                "show_ui" => true,
                "show_in_rest" => true,
                "rest_base" => "",
				"show_in_nav_menus" => true,
                "has_archive" => true,
                "show_in_menu" => true,
                "exclude_from_search" => false,
                "hierarchical" => false,
                "rewrite" => array( "slug" => "recipe", "with_front" => true ),
                "query_var" => true,
                "menu_icon" => "dashicons-carrot",
                "supports" => array( "title", "excerpt", "editor", "thumbnail", "comments", "author" ),
                //"capability_type" => array('recipe', 'recipes'),
				"capability_type" => "post",
                "map_meta_cap" => true,
                "taxonomies" => array("recipe_category", "recipe_tag"),
            );

            register_post_type( "recipe", $args );

        }

        public static function add_fields()
        {

            if( function_exists('acf_add_local_field_group') ):

                acf_add_local_field_group(array(
                    'key' => 'group_5a37a8a80ea89',
                    'title' => __('Recipe', 'dadevarzan-wp-recipe'),
                    'fields' => array(
                        array(
                            'key' => 'field_5a37a8cb5c6de',
                            'label' => __('Raw material image', 'dadevarzan-wp-recipe'),
                            'name' => 'rcp_ingrecient_pic',
                            'type' => 'image',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'return_format' => 'url',
                            'preview_size' => 'thumbnail',
                            'library' => 'all',
                            'min_width' => 400,
                            'min_height' => 200,
                            'min_size' => '',
                            'max_width' => 2000,
                            'max_height' => 1000,
                            'max_size' => '',
                            'mime_types' => 'jpeg,jpg,gif,png,svg',
                        ),
                        array(
                            'key' => 'field_5a37aa0a5c6df',
                            'label' => __('Preparation time', 'dadevarzan-wp-recipe'),
                            'name' => 'rcp_time',
                            'type' => 'number',
                            'instructions' => '',
                            'required' => 1,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => __('hour', 'dadevarzan-wp-recipe'),
                            'min' => 0,
                            'max' => 100,
                            'step' => '',
                        ),
                        array(
                            'key' => 'field_5a37abd25c6e0',
                            'label' => __('Enough for', 'dadevarzan-wp-recipe'),
                            'name' => 'rcp_person',
                            'type' => 'number',
                            'instructions' => '',
                            'required' => 1,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => __('People', 'dadevarzan-wp-recipe'),
                            'min' => 1,
                            'max' => 100,
                            'step' => '',
                        ),
                        array(
                            'key' => 'field_5a37ac175c6e1',
                            'label' => __('Material', 'dadevarzan-wp-recipe'),
                            'name' => 'rcp_ingrecients',
                            'type' => 'repeater',
                            'instructions' => '',
                            'required' => 1,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'collapsed' => '',
                            'min' => 0,
                            'max' => 0,
                            'layout' => 'table',
                            'button_label' => '',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5a37ac395c6e2',
                                    'label' => __('Material Name', 'dadevarzan-wp-recipe'),
                                    'name' => 'rcp_ingrecients_title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5a37ac635c6e3',
                                    'label' => __('Material measure', 'dadevarzan-wp-recipe'),
                                    'name' => 'rcp_ingrecients_value',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                        ),
                    ),
                    'location' => array(
                        array(
                            array(
                                'param' => 'post_type',
                                'operator' => '==',
                                'value' => 'recipe',
                            ),
                        ),
                    ),
                    'menu_order' => 0,
                    'position' => 'acf_after_title',
                    'style' => 'default',
                    'label_placement' => 'top',
                    'instruction_placement' => 'label',
                    'hide_on_screen' => '',
                    'active' => 1,
                    'description' => '',
                ));

            endif;

        }

        public static function add_taxonomy()
        {

            $labels = array(
                "name" => __('Recipe Categories', 'dadevarzan-wp-recipe'),
                "singular_name" => __('Recipe Category', 'dadevarzan-wp-recipe'),
            );

            $args = array(
                "label" => __('Recipe Categories', 'dadevarzan-wp-recipe'),
                "labels" => $labels,
                "public" => true,
                "hierarchical" => true,
                "show_ui" => true,
                "show_in_menu" => true,
                "show_in_nav_menus" => true,
                "query_var" => true,
                "rewrite" => array('slug' => 'recipe_category', 'with_front' => true,),
                "show_admin_column" => true,
                "show_in_rest" => true,
                "rest_base" => "",
                "show_in_quick_edit" => true,
                'capabilities' => array(
                    'manage_terms' => 'manage_categories',
                    'edit_terms' => 'manage_categories',
                    'delete_terms' => 'manage_categories',
                    'assign_term' => 'manage_categories',
                    'assign_terms' => 'manage_categories',
                ),
            );

            register_taxonomy('recipe_category', array('recipe'), $args);

            $labels = array(
                "name" => __('Recipe Tags', 'dadevarzan-wp-recipe'),
                "singular_name" => __('Recipe Tag', 'dadevarzan-wp-recipe'),
            );

            $args = array(
                "label" => __('Recipe tags', 'dadevarzan-wp-recipe'),
                "labels" => $labels,
                "public" => true,
                "hierarchical" => false,
                "show_ui" => true,
                "show_in_menu" => true,
                "show_in_nav_menus" => true,
                "query_var" => true,
                "rewrite" => array('slug' => 'recipe_tag', 'with_front' => true,),
                "show_admin_column" => true,
                "show_in_rest" => true,
                "rest_base" => "",
                "show_in_quick_edit" => true,
                'capabilities' => array(
                    'manage_terms' => 'manage_categories',
                    'edit_terms' => 'manage_categories',
                    'delete_terms' => 'manage_categories',
                    'assign_terms' => 'edit_recipe',
                ),
            );

            register_taxonomy('recipe_tag', array('recipe'), $args);

        }

        public static function add_role_caps()
        {

            // Add the roles you'd like to administer the custom post types
            $roles = array('wpseo_editor', 'wpseo_manager', 'shop_manager', 'editor', 'administrator');

            // Loop through each role and assign capabilities
            foreach($roles as $the_role) {

                $role = get_role($the_role);

                if ( empty($role) ) {
                    continue;
                }

                $role->add_cap( 'read' );
                $role->add_cap( 'read_recipe' );
                $role->add_cap( 'edit_recipe' );
                $role->add_cap( 'edit_recipes' );
                $role->add_cap( 'edit_private_recipes' );
                $role->add_cap( 'edit_published_recipes' );
                $role->add_cap( 'edit_others_recipes' );
                $role->add_cap( 'delete_recipe' );
                $role->add_cap( 'delete_recipes' );
                $role->add_cap( 'delete_private_recipes' );
                $role->add_cap( 'delete_published_recipes' );
                $role->add_cap( 'delete_others_recipes' );
                $role->add_cap( 'publish_recipes' );
                $role->add_cap( 'read_private_recipes' );

            }

        }

        public static function load_templates() {

            /**
             * Return if the builder isn't installed or if the current
             * version doesn't support registering templates.
             */
            if ( ! class_exists( 'FLBuilder' ) || ! method_exists( 'FLBuilder', 'register_templates' ) ) {
                return;
            }

            $layoutTemplatePath = plugin_dir_path( __FILE__ ) . 'data/templates.dat';
            if ( file_exists( $layoutTemplatePath ) && class_exists( 'FLThemeBuilder' ) ) {
                FLBuilder::register_templates( $layoutTemplatePath, array('group' => 'recipe'));
            }

        }

        public static function load_text_domain()
        {
            load_plugin_textdomain( 'dadevarzan-wp-recipe' , FALSE, basename( dirname( __FILE__ ) ) . '/languages'  );
        }

    }

    dadevarzanWpRecipe::initialize();

}
